@@ -16,7 +16,8 @@ __github_username__ = "MacHu-GWU"
 try:
     from . import better_boto
     from .org_struct import (
-        get_org_structure,
+        Node,
+        OrgStructure,
     )
-except ImportError:
+except ImportError: # pragma: no cover
     pass
