@@ -8,8 +8,13 @@ from .model import (
     AccountStatusEnum,
     AccountJoinedMethodEnum,
     Account,
-    OrganizationUnit,
+    OrganizationalUnit,
     Organization,
+
+    ParentIterproxy,
+    ChildIterproxy,
+    AccountIterproxy,
+    OrganizationUnitIterproxy,
 )
 
 from .org_unit import (
